﻿# AnyDesk (msi)
# 2018-2021 foo.li systeme + software
# http://support.anydesk.com/knowledgebase/articles/435750-automatic-deployment
# https://support.anydesk.com/Automatic_Deployment

$packageName    = 'foo-anydesk'
#msi installer macht "AnyDesk MSI", exe Installer nur "AnyDesk". exe version ist aber "ad 2.6.0"
$packageSearch  = 'AnyDesk*'
$version        = '7.0.4'
$installerType  = 'msi'
$url            = 'https://download.anydesk.com/AnyDesk.msi'
#$SilentArgs     = '--install "$env:ProgramFiles\AnyDesk" --remove-first --create-shortcuts --silent'
$silentArgs      = '/qb'
$validExitCodes = @(0,3010)
$checksum       = 'b4f169ff28f0345fd6350bd12f00ac36ff495fba'
$checksumType   = 'sha1'

function installAD {
    Install-ChocolateyPackage $packageName $fileType $silentArgs $url `
                                -checksum $checksum -checksumtype $checksumType
}

try {
    $app = Get-ItemProperty -Path @('HKLM:\Software\Wow6432Node\Microsoft\Windows\CurrentVersion\Uninstall\*',
                                    'HKLM:\Software\Microsoft\Windows\CurrentVersion\Uninstall\*') `
            -ErrorAction:SilentlyContinue | Where-Object { $_.DisplayName -like $packageSearch }

    if ($app -and ([version]$app.DisplayVersion -ge [version]$version)) {
        Write-Output $(
        'AnyDesk ('+$version +') is already installed. ' +
        'No need to install again.'
        )
    } elseif ($app -and ([version]$app.DisplayVersion -lt [version]$version)) {
        #old version needs to be uninstalled first
        #not yet tested... ;-)
        Write-Host 'removing previous anydesk version...'
        Uninstall-ChocolateyPackage $packageName $installerType $silentArgs $app.UninstallString
        installAD
    } else {
        installAD
    }
    Write-Host 'housekeeping...'
    Remove-Item -Path "$env:PUBLIC\Desktop\AnyDesk*.lnk"
} catch {
    throw $_.Exception
}
